.. image:: assets/logo_200w.png

|Python compat| |PyPi| |GHA tests| |Codecov report| |readthedocs|

.. inclusion-marker-do-not-remove

gnwmanager
==============

gnwmanager is a


Features
========

Installation
============

gnwmanager requires Python ``>=3.8`` and can be installed via:

.. code-block:: bash

   python -m pip install git+https://github.com/BrianPugh/gnwmanager-tmp.git


Usage
=====

.. code-block:: python

   import gnwmanager




.. |GHA tests| image:: https://github.com/BrianPugh/gnwmanager-tmp/workflows/tests/badge.svg
   :target: https://github.com/BrianPugh/gnwmanager-tmp/actions?query=workflow%3Atests
   :alt: GHA Status
.. |Codecov report| image:: https://codecov.io/github/BrianPugh/gnwmanager-tmp/coverage.svg?branch=main
   :target: https://codecov.io/github/BrianPugh/gnwmanager-tmp?branch=main
   :alt: Coverage
.. |readthedocs| image:: https://readthedocs.org/projects/gnwmanager-tmp/badge/?version=latest
        :target: https://gnwmanager-tmp.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status
.. |Python compat| image:: https://img.shields.io/badge/>=python-3.8-blue.svg
.. |PyPi| image:: https://img.shields.io/pypi/v/gnwmanager.svg
        :target: https://pypi.python.org/pypi/gnwmanager
